@@ -24,12 +24,31 @@ __email__ = "nesaro@gmail.com"
 import logging
 LOG = logging.getLogger(__name__)
 from pydsl.Memory.Loader import load_checker
-finalchar = "EOF"
+from pydsl.Alphabet.Token import Token
 unknownchar = "UNKNOWN"
 
+class AlphabetTranslator(object):
+    @property
+    def input_alphabet(self):
+        raise NotImplementedError
 
-class Lexer(object):
-    """Lexer follows an alphabet definition, which is like a grammar definition but generates a list of tokens and it is always Readable using a regular grammar"""
+    @property
+    def output_alphabet(self):
+        raise NotImplementedError
+
+class EncodingLexer(AlphabetTranslator):
+    """Special Lexer that encodes from a string a reads a string"""
+    def __init__(self, encoding):
+        self.encoding = encoding
+
+    def __call__(self, string):
+        for x in string:
+            yield Token(x)
+
+class Lexer(AlphabetTranslator):
+    """Lexer follows an alphabet definition.
+    generates a list of tokens and it
+    is always described with a regular grammar"""
     def __init__(self, generate_unknown=False):
         self.load(None)
         self.generate_unknown = generate_unknown
@@ -40,7 +59,7 @@ class Lexer(object):
         try:
             return self.string[self.index]
         except IndexError:
-            return finalchar
+            return None
 
     def load(self, string):
         self.string = string
@@ -53,7 +72,7 @@ class Lexer(object):
         if self.current == char:
             self.consume()
         else:
-            raise Exception
+            raise Exception("%s doesn't match %s"%(self.current,char))
 
     def nextToken(self):
         raise NotImplementedError
@@ -61,48 +80,40 @@ class Lexer(object):
     def __call__(self, string):# -> "TokenList":
         """Tokenizes input, generating a list of tokens"""
         self.string = string
-        result = []
         while True:
-            nt = self.nextToken()
-            result.append(nt)
-            if nt[0] == "EOF_TYPE":
-                return result
+            result = [x for x in self.nextToken()]
+            return result
 
 
 class BNFLexer(Lexer):
     """Generates a Lexer from a BNFGrammar instance"""
     def __init__(self, bnfgrammar):
         Lexer.__init__(self)
-        self.symbollist = bnfgrammar.getTerminalSymbols()
+        self.symbollist = bnfgrammar.terminalsymbollist
 
     @property
     def current(self):
         """Returns the element under the cursor until the end of the string"""
-        try:
-            return self.string[self.index:]
-        except IndexError:
-            return finalchar
+        return self.string[self.index:]
 
     def nextToken(self):
-        while self.current != finalchar:
-            validelements = [x for x in self.symbollist if self.current[0] in x.first()]
+        while self.current:
+            validelements = [x for x in self.symbollist if self.current[0] in x.first]
             if not validelements:
                 if not self.generate_unknown:
                     raise Exception("Not found")
                 string = self.current[0]
                 self.consume()
-                return unknownchar, string
+                yield Token(string)
             elif len(validelements) == 1:
                 element = validelements[0]
-                string = self.current[:len(element)]
-                for _ in range(len(element)):
+                string = self.current[:len(str(element))]
+                for _ in range(len(str(element))):
                     self.consume()
-                return validelements[0].name, string
+                yield Token(string)
             else:
                 raise Exception("Multiple choices")
 
-        return "EOF_TYPE", ""
-
 class AlphabetDictLexer(Lexer):
     def __init__(self, alphabet):
         Lexer.__init__(self)
@@ -111,10 +122,7 @@ class AlphabetDictLexer(Lexer):
     @property
     def current(self):
         """Returns the element under the cursor until the end of the string"""
-        try:
-            return self.string[self.index:]
-        except IndexError:
-            return finalchar
+        return self.string[self.index:]
 
     def nextToken(self):
         while self.current:
@@ -124,7 +132,7 @@ class AlphabetDictLexer(Lexer):
                     raise Exception("Not found")
                 string = self.current[0]
                 self.consume()
-                return unknownchar, string
+                yield Token(unknownchar, string)
             elif len(validelements) == 1:
                 element = validelements[0][1]
                 checker = load_checker(element)
@@ -136,9 +144,43 @@ class AlphabetDictLexer(Lexer):
                 string = self.current[:size]
                 for _ in range(size):
                     self.consume()
-                return validelements[0][0], string
+                yield Token(string, validelements[0][1])
             else:
                 raise Exception("Multiple choices")
 
-        return "EOF_TYPE", ""
+class AlphabetListLexer(Lexer):
+    def __init__(self, alphabet):
+        Lexer.__init__(self)
+        self.alphabet = alphabet
 
+    @property
+    def current(self):
+        """Returns the element under the cursor until the end of the string"""
+        return self.string[self.index:]
+
+    def nextToken(self):
+        while self.current:
+            from pydsl.Grammar.Definition import  StringGrammarDefinition
+            currentgd = StringGrammarDefinition(self.current[0])
+            print(currentgd)
+            validelements = [x for x in self.alphabet.grammar_list if currentgd in x.first]
+            if not validelements:
+                if not self.generate_unknown:
+                    raise Exception("Not found")
+                string = self.current[0]
+                self.consume()
+                yield Token(unknownchar, string)
+            elif len(validelements) == 1:
+                element = validelements[0]
+                checker = load_checker(element)
+                for size in range(element.maxsize or len(self.current), max(element.minsize-1,0), -1):
+                    if checker.check(self.current[:size]):
+                        break
+                else:
+                    raise Exception("Nothing consumed")
+                string = self.current[:size]
+                for _ in range(size):
+                    self.consume()
+                yield Token(string, validelements[0])
+            else:
+                raise Exception("Multiple choices" + str([str(x) for x in validelements]))
