@@ -17,7 +17,7 @@
 
 """Production rules"""
 
-from pydsl.Grammar.Symbol import Symbol, TerminalSymbol
+from pydsl.Grammar.Symbol import Symbol, TerminalSymbol, NullSymbol, EndSymbol
 from pydsl.Grammar.Definition import GrammarDefinition
 
 __author__ = "Nestor Arocha"
@@ -68,24 +68,74 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
         self._initialsymbol = initialsymbol
         for rule in fulllist:
             if fulllist.count(rule) >1:
-                raise ValueError
+                raise ValueError("Duplicated rule: " + str(rule))
         self.fulllist = fulllist
         if not options: options = {}
         self.options = options
 
+    def alphabet(self):
+        from pydsl.Alphabet.Definition import AlphabetListDefinition
+        return AlphabetListDefinition([x.gd for x in self.terminalsymbollist])
+
     @property
     def productionlist(self):
         return [x for x in self.fulllist if isinstance(x, Production)]
 
     @property
     def terminalsymbollist(self):
-        return [x for x in self.fulllist if isinstance(x,
-            TerminalSymbol)]
+        return [x for x in self.fulllist if isinstance(x, TerminalSymbol)]
+
+    @property
+    def symbollist(self):
+        result = []
+        for x in self.productionlist:
+            for y in x.leftside + x.rightside:
+                if y not in result:
+                    result.append(y)
+        return result
 
     @property
     def first(self):
+        """Returns the list of terminalsymbols that can be the first element of this grammar"""
         return [x.first for x in self.terminalsymbollist]
 
+    def first_lookup(self, symbol):
+        """Returns the first TerminalSymbols produced by the input symbol within this grammar definition"""
+        if isinstance(symbol, (TerminalSymbol, NullSymbol)):
+            return [symbol]
+        result = []
+        for x in self.productionlist:
+            if x.leftside[0] != symbol:
+                continue
+            for y in x.rightside:
+                current_symbol_first = self.first_lookup(y)
+                result += current_symbol_first
+                if NullSymbol not in current_symbol_first:
+                    break # This element doesn't have Null in its first set so there is no need to continue
+        if not result:
+            raise KeyError("Symbol doesn't exist in this grammar")
+        return result
+
+    def next_lookup(self, symbol):
+        """Returns the next TerminalSymbols produced by the input symbol within this grammar definition"""
+        result = []
+        if symbol == self.initialsymbol:
+            result.append(EndSymbol())
+        for production in self.productionlist:
+            if symbol in production.rightside:
+                nextindex = production.rightside.index(symbol)+1
+                while nextindex < len(production.rightside):
+                    nextsymbol = production.rightside[nextindex]
+                    firstlist = self.first_lookup(nextsymbol)
+                    cleanfirstlist = [x for x in firstlist if x != NullSymbol()]
+                    result.append(cleanfirstlist)
+                    if NullSymbol() not in firstlist:
+                        break
+                else:
+                    result += self.next_lookup(production.leftside[0]) #reached the end of the rightside
+
+        return result
+
     @property
     def left_recursive(self):# -> bool:
         """Tests if exists left recursion"""
@@ -192,122 +242,8 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
     def getProductions(self):
         return self.productionlist
 
-    def getTerminalSymbols(self):
-        """Returns a list with every terminal symbol """
-        return self.terminalsymbollist
-
     def getProductionIndex(self, rule):
         return self.productionlist.index(rule)
 
     def __str__(self):
         return str(list(map(str,self.productionlist)))
-
-def create_non_terminal_production(productionset, terminalsymbol):
-    """Creates a new nonterminalrule for terminalsymbol
-    A -> B,nt 
-    is changed to: 
-    A -> B,C  
-    C -> nt
-    """
-    #walks through all rules looking for our terminalsymbol in rightside
-    from .Symbol import NonTerminalSymbol
-    productionstochange = []
-    for index, production in enumerate(productionset[:]): #copy
-        if terminalsymbol in production.rightside:
-            for symbol in production.rightside:
-                if isinstance(symbol, NonTerminalSymbol):
-                    productionstochange.append(production)
-                    del productionset[index]
-                    break
-    #Inserts new rule
-    newsymbol = NonTerminalSymbol(str(terminalsymbol))
-    newproduction = Production(newsymbol, terminalsymbol)
-    productionset.append(newproduction)
-    #modifies required rules to link with new production
-    for production in productionstochange:
-        newproduction = Production(production.leftside[:], production.rightside[:])
-        for index, element in enumerate(production.rightside):
-            if element == terminalsymbol:
-                del newproduction.rightside[index]
-                newproduction.rightside.insert(index, newsymbol)
-        productionset.append(newproduction)
-    return productionset
-
-def reduce_non_terminal_production(productionset, uselesssymbol):
-    """search for production that only have nonterminalsymbol at right, subst nonterminal from rules at right and  remove the rule that have it at left"""
-    production = productionset.getProductionsBySide(uselesssymbol, "right")
-    productionset.remove(production)
-    validterminalsymbol = production.leftside[0] #usefulterminalymbol
-    productionlist = productionset.getProductionsBySide(uselesssymbol)
-    saverule = False
-
-    if len(productionlist) > 1:
-        saverule = True
-        #several rules with uselesssymbol at left
-
-    for production in productionset:    
-        if uselessnonterminal in production.rightside:
-            #adds those who have nonterminal at right 
-            newproduction = production.copy()
-            index = newproduction.index(uselessnonterminal)
-            del newproduction[index]
-            newproduction.insert(index, validterminalsymbol)
-            if not saverule:#Si no habia otra produccion
-                productionset.remove(production)
-
-
-def split_production(productionset, production):
-    from .Symbol import NonTerminalSymbol
-    if len(production.rightside) < 2:
-        return productionset
-    index = 0
-    productionset.remove(production)
-    newrightside = []
-    while index < len(production) - 2:
-        firsttwo = production.rightside[index:index+2]
-        newsymbol = NonTerminalSymbol(production.leftside[0].name + "E")
-        newrightside.append(newsymbol)
-        newproduction = Production(newsymbol, firsttwo)
-        productionset.append(newproduction)
-        index += 2
-    newrightside += production.rightside[index:]
-    newproduction = Production(production.leftside, newrightside)
-    productionset.append(newproduction)
-    return productionset
-
-
-def chomsky_normal_form(productionset):# -> BNFGrammar:
-    """TODO Check is Epsilon free"""
-    ntermslist = []
-    from .Symbol import NonTerminalSymbol
-    #STEP 1: A -> B,c 
-    #Terminal and nonterminal at right side 
-    for production in productionset:
-        termlist = 0
-        ntermlist = 0
-        for element in production.rightside:
-            if isinstance(element, TerminalSymbol):
-                termlist.append(element)
-            elif isinstance(element, NonTerminalSymbol):
-                ntermlist.append(element)
-        if termlist and ntermlist:
-            ntermslist += termlist
-    for terminal in ntermlist:
-        productionset = create_non_terminal_production(productionset, terminal)
-    #STEP 2: useless nonterminal
-    uselessnonterms = []
-    for production in productionset:
-        if len(production.rightside) == 1 and isinstance(production.rightside[0], NonTerminalSymbol):
-            uselessnonterms.append(production.rightside[0])
-    for nonterm in uselessnonterms:
-        productionset = reduce_non_terminal_production(productionset, nonterm)
-
-    #STEP 3:rightside is too long 
-    longproductions = []
-    for production in productionset:
-        if len(production.rightside) > 2:
-            longproductions.append(production)
-    for production in longproductions:
-        productionset = split_production(productionset, nonterm)
-
-    return productionset
