@@ -24,7 +24,7 @@ __email__ = "nesaro@gmail.com"
 
 import logging
 import re
-from pydsl.Grammar.Symbol import StringTerminalSymbol, WordTerminalSymbol,  NonTerminalSymbol, NullSymbol, UnknownSymbol
+from pydsl.Grammar.Symbol import TerminalSymbol,  NonTerminalSymbol, NullSymbol, UnknownSymbol
 from pydsl.Grammar.BNF import Production
 LOG = logging.getLogger(__name__)
 
@@ -37,14 +37,17 @@ def __generateStringSymbol(rightside):
     content = tail
     if len(tail) > 2 and tail[1][0] == "'" and tail[1][-1] == "'":
         content = tail[1][1:-1]
-    return StringTerminalSymbol(content)
+    from pydsl.Grammar.Definition import StringGrammarDefinition
+    return TerminalSymbol(StringGrammarDefinition(content))
 
 def __generateWordSymbol(rightside):
     args = rightside.split(",")
     if args[0] != "Word":
         raise TypeError
     br = args[2] #Boundary rule policy
-    return WordTerminalSymbol(args[1], {"grammarname":args[1]}, br)
+
+    from pydsl.Memory.Loader import load
+    return TerminalSymbol(load(args[1]), None, br)
 
 
 def read_nonterminal_production(line, symboldict):
@@ -129,8 +132,7 @@ def strlist_to_production_set(linelist):
                 linestodrop.append(myindex)
         linestodrop.reverse()
         if len(linestodrop) == 0:
-            LOG.error("No rule found: ")
-            raise Exception
+            raise Exception("No rule found: ")
         for myindex in linestodrop:
             del nonterminalrulelist[myindex]
     from pydsl.Grammar.BNF import BNFGrammar
