@@ -24,7 +24,7 @@ __email__ = "nesaro@gmail.com"
 
 def load_checker(grammar):
     from pydsl.Grammar.BNF import BNFGrammar
-    from pydsl.Grammar.Definition import PLYGrammar, RegularExpressionDefinition, MongoGrammar
+    from pydsl.Grammar.Definition import PLYGrammar, RegularExpressionDefinition, MongoGrammar, StringGrammarDefinition, PythonGrammar
     from pydsl.Alphabet.Definition import AlphabetDictDefinition
     if isinstance(grammar, str):
         grammar = load(grammar)
@@ -34,7 +34,7 @@ def load_checker(grammar):
     elif isinstance(grammar, RegularExpressionDefinition):
         from pydsl.Checker import RegularExpressionChecker
         return RegularExpressionChecker(grammar)
-    elif isinstance(grammar, dict) and "matchFun" in grammar:
+    elif isinstance(grammar, PythonGrammar) or isinstance(grammar, dict) and "matchFun" in grammar:
         from pydsl.Checker import PythonChecker
         return PythonChecker(grammar)
     elif isinstance(grammar, MongoGrammar):
@@ -46,41 +46,32 @@ def load_checker(grammar):
     elif isinstance(grammar, AlphabetDictDefinition):
         from pydsl.Checker import AlphabetDictChecker
         return AlphabetDictChecker(grammar)
+    elif isinstance(grammar, StringGrammarDefinition):
+        from pydsl.Checker import StringChecker
+        return StringChecker(grammar)
     elif isinstance(grammar, Encoding):
         from pydsl.Checker import EncodingChecker
         return EncodingChecker(grammar)
     else:
         raise ValueError(grammar)
 
-def load_grammar_tool(grammar):
-    from pydsl.Grammar.BNF import BNFGrammar
-    from pydsl.Grammar.Definition import RegularExpressionDefinition
-    from pydsl.Grammar.Tool.Python import PythonGrammarTools
-    if isinstance(grammar, str):
-        grammar = load(grammar)
-    if isinstance(grammar, BNFGrammar):
-        from pydsl.Grammar.Tool.Symbol import SymbolGrammarTools
-        return SymbolGrammarTools(grammar)
-    elif isinstance(grammar, RegularExpressionDefinition):
-        from pydsl.Grammar.Tool.Regular import RegularExpressionGrammarTools
-        return RegularExpressionGrammarTools(grammar)
-    elif isinstance(grammar, dict) and "matchFun" in grammar:
-        from pydsl.Grammar.Tool.Python import PythonGrammarTools
-        return PythonGrammarTools(grammar)
-    else:
-        raise ValueError(grammar)
-
 def load_lexer(alphabet):
-    from pydsl.Alphabet.Definition import AlphabetDictDefinition
+    from pydsl.Alphabet.Definition import AlphabetDictDefinition, AlphabetListDefinition
     from pydsl.Grammar.BNF import BNFGrammar
     if isinstance(alphabet, str):
         alphabet = load(alphabet)
     if isinstance(alphabet, AlphabetDictDefinition):
         from pydsl.Alphabet.Lexer import AlphabetDictLexer
         return AlphabetDictLexer(alphabet)
+    if isinstance(alphabet, AlphabetListDefinition):
+        from pydsl.Alphabet.Lexer import AlphabetListLexer
+        return AlphabetListLexer(alphabet)
     elif isinstance(alphabet, BNFGrammar):
         from pydsl.Alphabet.Lexer import BNFLexer
         return BNFLexer(alphabet)
+    elif isinstance(alphabet, Encoding):
+        from pydsl.Alphabet.Lexer import EncodingLexer
+        return EncodingLexer(alphabet)
     else:
         raise ValueError(alphabet)
 
@@ -101,7 +92,15 @@ def load_parser(grammar, parser = "auto"):
     else:
         raise ValueError(grammar)
 
-
+def load_validator(grammar):
+    if isinstance(grammar, str):
+        grammar = load(grammar)
+    from pydsl.Grammar.BNF import BNFGrammar
+    if isinstance(grammar, BNFGrammar):
+        from pydsl.Validate import BNFValidator
+        return BNFValidator(grammar)
+    else:
+        raise ValueError(grammar)
 
 def load(identifier, memorylist = None):
     if not memorylist:
